/*
 * #%L
 * OME-XML C++ library for working with OME-XML metadata structures.
 * %%
 * Copyright © 2006 - 2016 Open Microscopy Environment:
 *   - Massachusetts Institute of Technology
 *   - National Institutes of Health
 *   - University of Dundee
 *   - Board of Regents of the University of Wisconsin-Madison
 *   - Glencoe Software, Inc.
 * %%
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright notice,
 *    this list of conditions and the following disclaimer in the documentation
 *    and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDERS OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 *
 * The views and conclusions contained in the software and documentation are
 * those of the authors and should not be interpreted as representing official
 * policies, either expressed or implied, of any organization.
 * #L%
 */

/*─────────────────────────────────────────────────────────────────────────────
 *
 * THIS IS AUTOMATICALLY GENERATED CODE.  DO NOT MODIFY.
 *
 *─────────────────────────────────────────────────────────────────────────────
 */

#ifndef OME_XML_MODEL_MASK_H
#define OME_XML_MODEL_MASK_H

#include <algorithm>
#include <list>
#include <stdexcept>
#include <string>
#include <vector>

#include <ome/common/log.h>

#include <ome/common/xml/dom/Document.h>
#include <ome/common/xml/dom/Element.h>
#include <ome/common/xml/dom/Node.h>
#include <ome/common/xml/dom/NodeList.h>

#include <ome/xml/model/Shape.h>

namespace ome
{
  namespace xml
  {
    namespace model
    {

      // Forward declarations.
      class BinData;
      class OMEModel;

      /**
       * Mask model object.
       */
      class Mask : public Shape
      {
      private:
        class Impl;
        /// Private implementation details.
        ome::compat::shared_ptr<Impl> impl;

      public:
        /// Default constructor.
        Mask();

        /**
         * Copy constructor.
         *
         * @param copy the Mask to copy.
         */
        Mask (const Mask& copy);

        /// Destructor.
        virtual
        ~Mask ();

        /**
         * Create a Mask model object from DOM element.
         *
         * @param element root of the XML DOM tree to from which to
         * construct the model object graph.
         * @param model handler for the OME model used to track
         * instances and references seen during the update.
         * @throws EnumerationException if there is an error
         * instantiating an enumeration during model object creation,
         * or ModelException if there are any consistency or validity
         * errors found during processing.
         *
         * @returns a new model object.
         */
        static ome::compat::shared_ptr< Mask>
        create(const common::xml::dom::Element& element,
               ome::xml::model::OMEModel& model);

        // Documented in superclass.
        const std::string&
        elementName() const;

        // Documented in superclass.
        bool
        validElementName(const std::string& name) const;


        // -- OMEModelObject API methods --

        /// @copydoc ome::xml::model::OMEModelObject::update
        virtual void
        update(const common::xml::dom::Element&  element,
               ome::xml::model::OMEModel& model);

      public:
        // -- Mask API methods --

        /// @copydoc ome::xml::model::OMEModelObject::link
        bool
        link (ome::compat::shared_ptr<Reference>& reference,
              ome::compat::shared_ptr< ome::xml::model::OMEModelObject>& object);

        /**
         * Get the Y property.
         *
         * @returns the Y property.
         */
        double
        getY () const;

        /**
         * Set the Y property.
         *
         * @param y the value to set.
         */
        void
        setY (double y);

        /**
         * Get the X property.
         *
         * @returns the X property.
         */
        double
        getX () const;

        /**
         * Set the X property.
         *
         * @param x the value to set.
         */
        void
        setX (double x);

        /**
         * Get the Height property.
         *
         * @returns the Height property.
         */
        double
        getHeight () const;

        /**
         * Set the Height property.
         *
         * @param height the value to set.
         */
        void
        setHeight (double height);

        /**
         * Get the Width property.
         *
         * @returns the Width property.
         */
        double
        getWidth () const;

        /**
         * Set the Width property.
         *
         * @param width the value to set.
         */
        void
        setWidth (double width);

        /**
         * Get size of linked BinData list.
         *
         * @returns the size of the list.
         */
        std::vector<ome::compat::shared_ptr<ome::xml::model::BinData> >::size_type
        sizeOfBinDataList () const;

        /**
         * Get the BinData list.
         *
         * @returns a reference to the list.
         *
         */
        std::vector<ome::compat::shared_ptr<ome::xml::model::BinData> >&
        getBinDataList ();

        /**
         * Get the BinData list.
         *
         * @returns a reference to the list.
         *
         */
        const std::vector<ome::compat::shared_ptr<ome::xml::model::BinData> >&
        getBinDataList () const;

        /**
         * Get BinData.
         *
         * @param index the index number of the BinData.
         * @returns the BinData.
         * @throws std::out_of_range if the index is invalid.
         */
        ome::compat::shared_ptr<ome::xml::model::BinData>&
        getBinData (std::vector<ome::compat::shared_ptr<ome::xml::model::BinData> >::size_type index);

        /**
         * Get BinData.
         *
         * @param index the index number of the BinData.
         * @returns the BinData.
         * @throws std::out_of_range if the index is invalid.
         */
        const ome::compat::shared_ptr<ome::xml::model::BinData>&
        getBinData (std::vector<ome::compat::shared_ptr<ome::xml::model::BinData> >::size_type index) const;

        /**
         * Set BinData.
         *
         * @param index the index number of the BinData.
         * @param binData the BinData to set.
         * @throws std::out_of_range if the index is invalid.
         */
        void
        setBinData (std::vector<ome::compat::shared_ptr<ome::xml::model::BinData> >::size_type index,
                               ome::compat::shared_ptr<ome::xml::model::BinData>& binData);

        /**
         * Add BinData.
         *
         * @param binData the BinData to add.
         *
         * @todo Return list position?
         * @todo Detect and handle duplicates?
         */
        void
        addBinData (ome::compat::shared_ptr<ome::xml::model::BinData>& binData);

        /**
         * Remove BinData.
         *
         * @param binData the BinData to remove.
         *
         * @todo Doesn't the removal break the indexing?
         * @todo Does the removal deal with multiple instances; we
         * aren't preventing duplicates on insertion.
         */
        void
        removeBinData (ome::compat::shared_ptr<ome::xml::model::BinData>& binData);

        const std::string&
        getShapeType() const;

        /// @copydoc ome::xml::model::OMEModelObject::asXMLElement
        virtual common::xml::dom::Element
        asXMLElement (common::xml::dom::Document& document) const;


      protected:
        // Documented in base class.
        virtual common::xml::dom::Element
        asXMLElementInternal (common::xml::dom::Document& document,
                              common::xml::dom::Element&  element) const;

      public:
       // Documented in superclass.
       const std::string&
       getXMLNamespace() const;
      };

    }
  }
}

#endif // OME_XML_MODEL_MASK_H

/*
 * Local Variables:
 * mode:C++
 * End:
 */
